# remirepo spec file for php-pecl-csv
#
# SPDX-FileCopyrightText:  Copyright 2020-2025 Remi Collet
# SPDX-License-Identifier: CECILL-2.1
# http://www.cecill.info/licences/Licence_CeCILL_V2-en.txt
#
# Please, preserve the changelog entries
#
%{?scl:%scl_package php-pecl-csv}

%bcond_without      tests

%global with_zts    0%{!?_without_zts:%{?__ztsphp:1}}
%global pie_vend    girgias
%global pie_proj    csv
%global proj_name   CSV
%global pecl_name   csv
%global ini_name    40-%{pecl_name}.ini
%global sources     %{proj_name}-%{version}
%global _configure  ../%{sources}/configure

Summary:        CSV PHP extension
Name:           %{?scl_prefix}php-pecl-%{pecl_name}
Version:        0.4.3
Release:        1%{?dist}%{!?scl:%{!?nophptag:%(%{__php} -r 'echo ".".PHP_MAJOR_VERSION.".".PHP_MINOR_VERSION;')}}
License:        PHP-3.01
URL:            https://pecl.php.net/package/%{proj_name}
Source0:        https://pecl.php.net/get/%{sources}.tgz

BuildRequires:  make
BuildRequires:  %{?dtsprefix}gcc
BuildRequires:  %{?scl_prefix}php-devel >= 8.0
BuildRequires:  %{?scl_prefix}php-pear

Requires:       %{?scl_prefix}php(zend-abi) = %{php_zend_api}
Requires:       %{?scl_prefix}php(api) = %{php_core_api}

Provides:       %{?scl_prefix}php-%{pecl_name}                 = %{version}
Provides:       %{?scl_prefix}php-%{pecl_name}%{?_isa}         = %{version}
Provides:       %{?scl_prefix}php-pecl(%{proj_name})           = %{version}
Provides:       %{?scl_prefix}php-pecl(%{proj_name})%{?_isa}   = %{version}
Provides:       %{?scl_prefix}php-pie(%{pie_vend}/%{pie_proj}) = %{version}


%description
A new and improved CSV file PHP extension which follows RFC 4180 instead of
using a custom escape mechanism.

Supports multi-bytes delimiters, enclosures, and providing a custom EOL
sequence.

Package built for PHP %(%{__php} -r 'echo PHP_MAJOR_VERSION.".".PHP_MINOR_VERSION;')%{?scl: as Software Collection (%{scl} by %{?scl_vendor}%{!?scl_vendor:rh})}.


%prep
%setup -q -c

# Don't install tests
sed -e 's/role="test"/role="src"/' \
    -e '/LICENSE/s/role="doc"/role="src"/' \
    -i package.xml

cd %{sources}
find . -type f -exec chmod -x {} \;
: Sanity check, really often broken
extver=$(sed -n '/# define PHP_CSV_VERSION /{s/.* "//;s/".*$//;p}' php_csv.h)
if test "x${extver}" != "x%{version}"; then
   : Error: Upstream extension version is ${extver}, expecting %{version}.
   exit 1
fi
cd ..

mkdir NTS
%if %{with_zts}
mkdir ZTS
%endif

# Create configuration file
cat << 'EOF' | tee %{ini_name}
; Enable %{pecl_name} extension module
extension=%{pecl_name}.so
EOF


%build
%{?dtsenable}

cd %{sources}
%{__phpize}
sed -e 's/INSTALL_ROOT/DESTDIR/' -i build/Makefile.global

cd ../NTS
%configure \
    --enable-csv \
    --with-php-config=%{__phpconfig}

%make_build

%if %{with_zts}
cd ../ZTS
%configure \
    --enable-csv \
    --with-php-config=%{__ztsphpconfig}

%make_build
%endif


%install
%{?dtsenable}

%make_install -C NTS

# install config file
install -D -m 644 %{ini_name} %{buildroot}%{php_inidir}/%{ini_name}

# Install XML package description
install -D -m 644 package.xml %{buildroot}%{pecl_xmldir}/%{name}.xml

%if %{with_zts}
%make_install -C ZTS

install -D -m 644 %{ini_name} %{buildroot}%{php_ztsinidir}/%{ini_name}
%endif

# Documentation
for i in $(grep 'role="doc"' package.xml | sed -e 's/^.*name="//;s/".*$//')
do install -Dpm 644 %{sources}/$i %{buildroot}%{pecl_docdir}/%{pecl_name}/$i
done


%check
cd %{sources}

: Minimal load test for NTS extension
%{__php} --no-php-ini \
    --define extension=%{buildroot}%{php_extdir}/%{pecl_name}.so \
    --modules | grep -i '^%{pecl_name}$'

%if %{with tests}
: Upstream test suite for NTS extension
TEST_PHP_ARGS="-n -d extension=$PWD/../NTS/modules/%{pecl_name}.so" \
%{__php} -n run-tests.php -q --show-diff
%endif

%if %{with_zts}
: Minimal load test for ZTS extension
%{__ztsphp} --no-php-ini \
    --define extension=%{buildroot}%{php_ztsextdir}/%{pecl_name}.so \
    --modules | grep -i '^%{pecl_name}$'

%if %{with tests}
: Upstream test suite for ZTS extension
TEST_PHP_ARGS="-n -d extension=$PWD/../ZTS/modules/%{pecl_name}.so" \
%{__ztsphp} -n run-tests.php -q --show-diff
%endif
%endif


%files
%license %{sources}/LICENSE
%doc %{pecl_docdir}/%{pecl_name}

%{pecl_xmldir}/%{name}.xml
%config(noreplace) %{php_inidir}/%{ini_name}
%{php_extdir}/%{pecl_name}.so

%if %{with_zts}
%config(noreplace) %{php_ztsinidir}/%{ini_name}
%{php_ztsextdir}/%{pecl_name}.so
%endif


%changelog
* Sun Feb 23 2025 Remi Collet <remi@remirepo.net> - 0.4.3-1
- update to 0.4.3
- re-license spec file to CECILL-2.1

* Thu Aug 31 2023 Remi Collet <remi@remirepo.net> - 0.4.2-3
- build out of sources tree

* Thu Sep  1 2022 Remi Collet <remi@remirepo.net> - 0.4.2-2
- rebuild for PHP 8.2.0RC1

* Wed Jun  1 2022 Remi Collet <remi@remirepo.net> - 0.4.2-1
- update to 0.4.2

* Mon Sep  6 2021 Remi Collet <remi@remirepo.net> - 0.4.1-1
- update to 0.4.1

* Tue Feb 23 2021 Remi Collet <remi@remirepo.net> - 0.4.0-1
- update to 0.4.0
- raise dependency on PHP 8

* Wed Sep 30 2020 Remi Collet <remi@remirepo.net> - 0.3.1-2.7.3
- rebuild for PHP 8.0.0RC1

* Thu Mar  5 2020 Remi Collet <remi@remirepo.net> - 0.3.1-1
- update to 0.3.1

* Wed Mar  4 2020 Remi Collet <remi@remirepo.net> - 0.3.0-1
- initial package, version 0.3.0 (stable)
- open https://gitlab.com/Girgias/csv-php-extension/issues/1 bad perms
- open https://gitlab.com/Girgias/csv-php-extension/issues/2 tests
- open https://gitlab.com/Girgias/csv-php-extension/-/merge_requests/3 CR/LF
- add patch for old GCC from
  https://gitlab.com/Girgias/csv-php-extension/-/merge_requests/4
